/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-25 13:52:52.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.common.aspect;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.core.print.common.Result;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

@ControllerAdvice(annotations = Controller.class)
public class AspectController {
    private final static Logger log = LoggerFactory.getLogger(AspectController.class);
    public final static HttpStatus ERROR_CODE = HttpStatus.INTERNAL_SERVER_ERROR;
    public final static String ERROR_CONTENT = "系统异常！";

    @ResponseBody
    @ExceptionHandler(value = RuntimeException.class)
    public ResponseEntity<String> handle(RuntimeException e) {
        return doHandle(e);
    }

    @ResponseBody
    @ExceptionHandler(value = Exception.class)
    public ResponseEntity<String> handle(Exception e) {
        return doHandle(e);
    }

    public static ResponseEntity<String> doHandle(Exception e) {
        if (e instanceof StatusException) {
            StatusException se = (StatusException) e;
            log.error(se.toJson());
            return new ResponseEntity<>(se.toJson(), ERROR_CODE);
        }
        log.error(e.getMessage(), e);
        String errorJson = Result.error(ERROR_CONTENT).toJson();
        return new ResponseEntity<>(errorJson, ERROR_CODE);
    }

}