/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-17 15:18:02.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.common.utils;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;

import java.lang.reflect.Array;
import java.util.Collection;
import java.util.Map;

import static cn.com.qmth.examcloud.core.print.common.Constants.PRT_CODE_400;

/**
 * 参数校验类
 *
 * @author: fengdesheng
 * @since: 2018/10/17
 */
public class Check {

    public static void isNull(Object obj, String message) {
        if (obj == null) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    public static void isEmpty(Object obj, String message) {
        if (isEmpty(obj)) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    public static void isEmpty(Object[] array, String message) {
        if (isEmpty(array)) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    public static void isEmpty(Collection<?> collection, String message) {
        if (isEmpty(collection)) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    public static void isEmpty(Map<?, ?> map, String message) {
        if (isEmpty(map)) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    public static void isBlank(CharSequence str, String message) {
        if (isBlank(str)) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    public static void isTrue(Boolean expression, String message) {
        if (expression != null && expression) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    public static void isFalse(Boolean expression, String message) {
        if (expression == null || !expression) {
            throw new StatusException(PRT_CODE_400, message);
        }
    }

    private static boolean isEmpty(Object obj) {
        if (obj == null) {
            return true;
        } else if (obj instanceof CharSequence) {
            return ((CharSequence) obj).length() == 0;
        } else if (obj.getClass().isArray()) {
            return Array.getLength(obj) == 0;
        } else if (obj instanceof Collection) {
            return ((Collection) obj).isEmpty();
        } else {
            return obj instanceof Map ? ((Map) obj).isEmpty() : false;
        }
    }

    private static boolean isBlank(CharSequence cs) {
        int strLen;
        if (cs != null && (strLen = cs.length()) != 0) {
            for (int i = 0; i < strLen; ++i) {
                if (!Character.isWhitespace(cs.charAt(i))) {
                    return false;
                }
            }
            return true;
        } else {
            return true;
        }
    }

}