/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-17 16:31:14.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service;

import cn.com.qmth.examcloud.core.print.entity.PrintingProject;
import cn.com.qmth.examcloud.core.print.service.bean.common.ExamInfo;
import cn.com.qmth.examcloud.core.print.service.bean.printingproject.PrintingProjectInfo;
import cn.com.qmth.examcloud.core.print.service.bean.printingproject.PrintingProjectQuery;
import org.springframework.data.domain.Page;

/**
 * 印刷项目相关接口
 *
 * @author: fengdesheng
 * @since: 2018/10/17
 */
public interface PrintingProjectService {

    /**
     * 查询印刷项目列表(分页)
     */
    Page<PrintingProjectInfo> getPrintingProjectList(PrintingProjectQuery query);

    /**
     * 获取某印刷项目的信息
     */
    PrintingProjectInfo getPrintingProjectById(Long id);

    /**
     * 获取某印刷项目的信息(By orgId & examId)
     */
    PrintingProject getPrintingProjectByOrgIdAndExamId(Long orgId, Long examId);

    /**
     * 更新印刷项目信息
     */
    void updatePrintingProject(PrintingProjectInfo info);

    /**
     * 同步(新增或更新)某个印刷项目的基本信息
     * 仅同步学校、考试等信息
     */
    void syncPrintingProject(ExamInfo examInfo);

    /**
     * 同步所有印刷项目的基本信息
     */
    void syncAllPrintingProject();

    /**
     * 同步更新学校名称信息
     */
    void syncPrintingProjectOrgName(Long orgId, String orgName);

    /**
     * 同步更新考试名称信息
     */
    void syncPrintingProjectExamName(Long examId, String examName);

    /**
     * 同步更新项目经理名称信息
     */
    void syncPrintingProjectPmName(Long pmId, String pmName);

    /**
     * 同步更新供应商名称信息
     */
    void syncPrintingProjectSupplierName(Long supplierId, String supplierName);

}