/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-26 18:28:34.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.impl;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.core.print.common.utils.Check;
import cn.com.qmth.examcloud.core.print.entity.PrintingProject;
import cn.com.qmth.examcloud.core.print.entity.ProjectStatistic;
import cn.com.qmth.examcloud.core.print.repository.ProjectStatisticRepository;
import cn.com.qmth.examcloud.core.print.service.CourseStatisticService;
import cn.com.qmth.examcloud.core.print.service.PrintingProjectService;
import cn.com.qmth.examcloud.core.print.service.PrintingProjectStatisticService;
import cn.com.qmth.examcloud.core.print.service.bean.printingproject.ProjectStatisticInfo;
import cn.com.qmth.examcloud.core.print.service.bean.projectstatistic.PrintingStatisticConvert;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import static cn.com.qmth.examcloud.core.print.common.Constants.PRT_CODE_500;

/**
 * @author: fengdesheng
 * @since: 2018/10/26
 */
@Service
public class PrintingProjectStatisticServiceImpl implements PrintingProjectStatisticService {
    private static final Logger log = LoggerFactory.getLogger(PrintingProjectStatisticServiceImpl.class);
    @Autowired
    private ProjectStatisticRepository projectStatisticRepository;
    @Autowired
    private PrintingProjectService printingProjectService;
    @Autowired
    private CourseStatisticService courseStatisticService;

    @Override
    public ProjectStatisticInfo getPrintingProjectStatistic(Long orgId, Long examId) {
        Check.isNull(orgId, "学校ID不能为空！");
        Check.isNull(examId, "考试ID不能为空！");
        PrintingProject project = printingProjectService.getPrintingProjectByOrgIdAndExamId(orgId, examId);
        if (project == null) {
            throw new StatusException(PRT_CODE_500, "当前项目不存在！");
        }
        ProjectStatistic statistic = projectStatisticRepository.getProjectStatisticByProjectId(project.getId());
        if (statistic == null) {
            //throw new StatusException(PRT_CODE_500, "当前项目统计不存在！");
        }
        return PrintingStatisticConvert.of(project, statistic);
    }

    @Override
    public void initPrintingProjectStatistic(Long projectId) {
        //todo init
    }

    @Override
    public void initAllPrintingProjectStatistic() {
        //todo init
    }

}