/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-22 15:30:03.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.impl;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.core.print.common.jpa.SearchBuilder;
import cn.com.qmth.examcloud.core.print.common.utils.Check;
import cn.com.qmth.examcloud.core.print.entity.ProjectOtherSetting;
import cn.com.qmth.examcloud.core.print.repository.ProjectOtherSettingRepository;
import cn.com.qmth.examcloud.core.print.service.ProjectOtherSettingService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import java.util.List;

import static cn.com.qmth.examcloud.core.print.common.Constants.PRT_CODE_500;

/**
 * @author: fengdesheng
 * @since: 2018/10/17
 */
@Service
public class ProjectOtherSettingServiceImpl implements ProjectOtherSettingService {
    private static final Logger log = LoggerFactory.getLogger(ProjectOtherSettingServiceImpl.class);
    @Autowired
    private ProjectOtherSettingRepository projectOtherSettingRepository;

    @Override
    public List<ProjectOtherSetting> getProjectOtherSettingList(Long projectId) {
        Check.isNull(projectId, "项目ID不能为空！");
        Specification<ProjectOtherSetting> spec = SearchBuilder.EQ("projectId", projectId);
        return projectOtherSettingRepository.findAll(spec);
    }

    @Override
    public ProjectOtherSetting getProjectOtherSettingById(Long id) {
        ProjectOtherSetting setting = projectOtherSettingRepository.findOne(id);
        if (setting == null) {
            throw new StatusException(PRT_CODE_500, "当前事项设置的信息不存在！");
        }
        return setting;
    }

    @Override
    public void saveProjectOtherSetting(ProjectOtherSetting info) {
        Check.isNull(info, "事项设置信息不能为空！");
        Check.isNull(info.getProjectId(), "事项设置的项目ID不能为空！");
        Check.isBlank(info.getRemark(), "事项设置的内容不能为空！");
        projectOtherSettingRepository.save(info);
    }

    @Override
    public void deleteProjectOtherSettingById(Long id) {
        try {
            projectOtherSettingRepository.delete(id);
        } catch (EmptyResultDataAccessException e) {
            //ignore: record not exist
            log.warn(e.getMessage());
        }
    }

}